==> jc-1.4.0.tar.gz: javax/net/ssl/SSLPermission.h <==
// public final class javax.net.ssl.SSLPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 29099fdf8810034f javax_net_ssl_SSLPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_javax_net_ssl_SSLPermission_H_
#define _JC_javax_net_ssl_SSLPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLPermission$sub_refs	_jc_javax_net_ssl_SSLPermission$sub_refs;
typedef struct _jc_javax_net_ssl_SSLPermission$sub_nonrefs	_jc_javax_net_ssl_SSLPermission$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLPermission$refs	_jc_javax_net_ssl_SSLPermission$refs;
typedef struct _jc_javax_net_ssl_SSLPermission$nonrefs	_jc_javax_net_ssl_SSLPermission$nonrefs;
typedef struct _jc_javax_net_ssl_SSLPermission$object	_jc_javax_net_ssl_SSLPermission$object;

typedef struct _jc_javax_net_ssl_SSLPermission$fields_struct	_jc_javax_net_ssl_SSLPermission$fields_struct;
typedef const struct _jc_javax_net_ssl_SSLPermission$vmethods	_jc_javax_net_ssl_SSLPermission$vmethods;
typedef const struct _jc_javax_net_ssl_SSLPermission$vtable	_jc_javax_net_ssl_SSLPermission$vtable;
typedef const struct _jc_javax_net_ssl_SSLPermission$vtype	_jc_javax_net_ssl_SSLPermission$vtype;

// Class fields structure
struct _jc_javax_net_ssl_SSLPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_net_ssl_SSLPermission$fields_struct _jc_javax_net_ssl_SSLPermission$class_fields;

// Constructors
extern void _jc_javax_net_ssl_SSLPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_net_ssl_SSLPermission$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_net_ssl_SSLPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_net_ssl_SSLPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_net_ssl_SSLPermission$vmethods {
};

// Vtable
struct _jc_javax_net_ssl_SSLPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_javax_net_ssl_SSLPermission$vmethods	javax_net_ssl_SSLPermission;
};

// Vtype
struct _jc_javax_net_ssl_SSLPermission$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLPermission$refs {
    _jc_javax_net_ssl_SSLPermission$sub_refs	javax_net_ssl_SSLPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_javax_net_ssl_SSLPermission$sub_nonrefs	javax_net_ssl_SSLPermission;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLPermission$object {
	_jc_javax_net_ssl_SSLPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLPermission$vtype	*vtype;
	_jc_javax_net_ssl_SSLPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLPermission$vtype _jc_javax_net_ssl_SSLPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLPermission$class_object;

#endif	/* _JC_javax_net_ssl_SSLPermission_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/SSLPermission.h <==
// public final class javax.net.ssl.SSLPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 29099fdf8810034f javax_net_ssl_SSLPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_javax_net_ssl_SSLPermission_H_
#define _JC_javax_net_ssl_SSLPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLPermission$sub_refs	_jc_javax_net_ssl_SSLPermission$sub_refs;
typedef struct _jc_javax_net_ssl_SSLPermission$sub_nonrefs	_jc_javax_net_ssl_SSLPermission$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLPermission$refs	_jc_javax_net_ssl_SSLPermission$refs;
typedef struct _jc_javax_net_ssl_SSLPermission$nonrefs	_jc_javax_net_ssl_SSLPermission$nonrefs;
typedef struct _jc_javax_net_ssl_SSLPermission$object	_jc_javax_net_ssl_SSLPermission$object;

typedef struct _jc_javax_net_ssl_SSLPermission$fields_struct	_jc_javax_net_ssl_SSLPermission$fields_struct;
typedef const struct _jc_javax_net_ssl_SSLPermission$vmethods	_jc_javax_net_ssl_SSLPermission$vmethods;
typedef const struct _jc_javax_net_ssl_SSLPermission$vtable	_jc_javax_net_ssl_SSLPermission$vtable;
typedef const struct _jc_javax_net_ssl_SSLPermission$vtype	_jc_javax_net_ssl_SSLPermission$vtype;

// Class fields structure
struct _jc_javax_net_ssl_SSLPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_net_ssl_SSLPermission$fields_struct _jc_javax_net_ssl_SSLPermission$class_fields;

// Constructors
extern void _jc_javax_net_ssl_SSLPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_net_ssl_SSLPermission$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_net_ssl_SSLPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_net_ssl_SSLPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_net_ssl_SSLPermission$vmethods {
};

// Vtable
struct _jc_javax_net_ssl_SSLPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_javax_net_ssl_SSLPermission$vmethods	javax_net_ssl_SSLPermission;
};

// Vtype
struct _jc_javax_net_ssl_SSLPermission$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLPermission$refs {
    _jc_javax_net_ssl_SSLPermission$sub_refs	javax_net_ssl_SSLPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_javax_net_ssl_SSLPermission$sub_nonrefs	javax_net_ssl_SSLPermission;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLPermission$object {
	_jc_javax_net_ssl_SSLPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLPermission$vtype	*vtype;
	_jc_javax_net_ssl_SSLPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLPermission$vtype _jc_javax_net_ssl_SSLPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLPermission$class_object;

#endif	/* _JC_javax_net_ssl_SSLPermission_H_ */
